@@ -20,6 +20,10 @@ from .healpix import (
     write_healpix_map_to_hdu,
     write_healpix_map_to_file,
 )
+from .hwp import (
+    HWP,
+    IdealHWP,
+)
 from .imo import (
     Imo,
     FormatSpecification,
@@ -33,6 +37,11 @@ from .hwp_sys.hwp_sys import HwpSys
 from .mbs.mbs import Mbs, MbsParameters, MbsSavedMapInfo
 from .mpi import MPI_COMM_WORLD, MPI_ENABLED, MPI_CONFIGURATION
 from .observations import Observation
+from .pointings import (
+    apply_hwp_to_obs,
+    get_pointing_buffer_shape,
+    get_pointings,
+)
 from .quaternions import (
     quat_rotation_x,
     quat_rotation_y,
@@ -59,14 +68,24 @@ from .scanning import (
     SpinningScanningStrategy,
     get_det2ecl_quaternions,
     get_ecl2det_quaternions,
-    get_pointings,
 )
 from .mapping import make_bin_map
 from .destriper import DestriperParameters, DestriperResult, destripe
 from .simulations import Simulation
-from .noise import add_noise
+from .noise import (
+    add_white_noise,
+    add_one_over_f_noise,
+    add_noise,
+    add_noise_to_observations,
+)
 from .scan_map import scan_map, scan_map_in_observations
-from .coordinates import DEFAULT_COORDINATE_SYSTEM, DEFAULT_TIME_SCALE
+from .coordinates import (
+    DEFAULT_COORDINATE_SYSTEM,
+    DEFAULT_TIME_SCALE,
+    ECL_TO_GAL_ROT_MATRIX,
+    CoordinateSystem,
+)
+
 from .spacecraft import (
     compute_l2_pos_and_vel,
     compute_lissajous_pos_and_vel,
@@ -115,6 +134,9 @@ __all__ = [
     "FreqChannelInfo",
     "InstrumentInfo",
     "detector_list_from_parameters",
+    # hwp.py
+    "HWP",
+    "IdealHWP",
     # mbs.py
     "Mbs",
     "MbsParameters",
@@ -150,6 +172,9 @@ __all__ = [
     "SpinningScanningStrategy",
     "get_det2ecl_quaternions",
     "get_ecl2det_quaternions",
+    # pointings.py
+    "apply_hwp_to_obs",
+    "get_pointing_buffer_shape",
     "get_pointings",
     # mapping.py
     "make_bin_map",
@@ -160,7 +185,10 @@ __all__ = [
     # simulations.py
     "Simulation",
     # noise.py
+    "add_white_noise",
+    "add_one_over_f_noise",
     "add_noise",
+    "add_noise_to_observations",
     # scan_map.py
     "scan_map",
     "scan_map_in_observations",
@@ -171,6 +199,8 @@ __all__ = [
     # coordinates.py
     "DEFAULT_COORDINATE_SYSTEM",
     "DEFAULT_TIME_SCALE",
+    "ECL_TO_GAL_ROT_MATRIX",
+    "CoordinateSystem",
     # spacecraft.py
     "compute_l2_pos_and_vel",
     "compute_lissajous_pos_and_vel",
