@@ -85,19 +85,22 @@ class HwpSys:
 
         # This part sets from parameter file
         if (self.sim.parameter_file is not None) and (
-            "hwp_sys" in self.sim.parameters.keys()
+            "hwp_sys" in self.sim.parameter_file.keys()
         ):
-            paramdict = self.sim.parameters["hwp_sys"]
+            paramdict = self.sim.parameter_file["hwp_sys"]
 
             if "nside" in paramdict.keys():
                 self.nside = paramdict["nside"]
-                if "general" in self.sim.parameters.keys():
-                    if "nside" in self.sim.parameters["general"].keys():
-                        if self.sim.parameters["general"]["nside"] != self.nside:
+                if "general" in self.sim.parameter_file.keys():
+                    if "nside" in self.sim.parameter_file["general"].keys():
+                        if self.sim.parameter_file["general"]["nside"] != self.nside:
                             print(
                                 "Warning!! nside from general "
                                 "(=%i) and hwp_sys (=%i) do not match. Using hwp_sys"
-                                % (self.sim.parameters["general"]["nside"], self.nside)
+                                % (
+                                    self.sim.parameter_file["general"]["nside"],
+                                    self.nside,
+                                )
                             )
 
             if "integrate_in_band" in paramdict.keys():
@@ -272,7 +275,7 @@ class HwpSys:
 
         if self.correct_in_solver:
             if self.integrate_in_band_solver:
-                self.h1, self.h2, self.beta, self.z1, self.z2 = np.loadtxt(
+                self.h1s, self.h2s, self.betas, self.z1s, self.z2s = np.loadtxt(
                     self.band_filename_solver,
                     usecols=(1, 2, 3, 4, 5),
                     unpack=True,
@@ -299,7 +302,7 @@ class HwpSys:
                  If the tod is not required, obs.tod can be not allocated
                  i.e. in lbs.Observation allocate_tod=False.
              pointings (float): pointing for each sample and detector
-                 generated by func:lbs.scanning.get_pointings
+                 generated by func:lbs.get_pointings
              hwp_radpsec (float): hwp rotation speed in radiants per second
         """
 
@@ -323,9 +326,9 @@ class HwpSys:
 
             if self.integrate_in_band:
                 J11 = (
-                    (1 + self.h1[:, np.newaxis]) * ca ** 2
+                    (1 + self.h1[:, np.newaxis]) * ca**2
                     - (1 + self.h2[:, np.newaxis])
-                    * sa ** 2
+                    * sa**2
                     * np.exp(1j * self.beta[:, np.newaxis])
                     - (self.z1[:, np.newaxis] + self.z2[:, np.newaxis]) * ca * sa
                 )
@@ -337,8 +340,8 @@ class HwpSys:
                     )
                     * ca
                     * sa
-                    + self.z1[:, np.newaxis] * ca ** 2
-                    - self.z2[:, np.newaxis] * sa ** 2
+                    + self.z1[:, np.newaxis] * ca**2
+                    - self.z2[:, np.newaxis] * sa**2
                 )
 
                 if self.built_map_on_the_fly:
@@ -370,14 +373,14 @@ class HwpSys:
 
             else:
                 J11 = (
-                    (1 + self.h1) * ca ** 2
-                    - (1 + self.h2) * sa ** 2 * np.exp(1j * self.beta)
+                    (1 + self.h1) * ca**2
+                    - (1 + self.h2) * sa**2 * np.exp(1j * self.beta)
                     - (self.z1 + self.z2) * ca * sa
                 )
                 J12 = (
                     ((1 + self.h1) + (1 + self.h2) * np.exp(1j * self.beta)) * ca * sa
-                    + self.z1 * ca ** 2
-                    - self.z2 * sa ** 2
+                    + self.z1 * ca**2
+                    - self.z2 * sa**2
                 )
 
                 if self.built_map_on_the_fly:
@@ -403,9 +406,9 @@ class HwpSys:
 
                     if self.integrate_in_band_solver:
                         J11 = (
-                            (1 + self.h1s[:, np.newaxis]) * ca ** 2
+                            (1 + self.h1s[:, np.newaxis]) * ca**2
                             - (1 + self.h2s[:, np.newaxis])
-                            * sa ** 2
+                            * sa**2
                             * np.exp(1j * self.betas[:, np.newaxis])
                             - (self.z1s[:, np.newaxis] + self.z2s[:, np.newaxis])
                             * ca
@@ -419,21 +422,21 @@ class HwpSys:
                             )
                             * ca
                             * sa
-                            + self.z1s[:, np.newaxis] * ca ** 2
-                            - self.z2s[:, np.newaxis] * sa ** 2
+                            + self.z1s[:, np.newaxis] * ca**2
+                            - self.z2s[:, np.newaxis] * sa**2
                         )
                     else:
                         J11 = (
-                            (1 + self.h1s) * ca ** 2
-                            - (1 + self.h2s) * sa ** 2 * np.exp(1j * self.betas)
+                            (1 + self.h1s) * ca**2
+                            - (1 + self.h2s) * sa**2 * np.exp(1j * self.betas)
                             - (self.z1s + self.z2s) * ca * sa
                         )
                         J12 = (
                             ((1 + self.h1s) + (1 + self.h2s) * np.exp(1j * self.betas))
                             * ca
                             * sa
-                            + self.z1s * ca ** 2
-                            - self.z2s * sa ** 2
+                            + self.z1s * ca**2
+                            - self.z2s * sa**2
                         )
 
                     del (ca, sa)
@@ -482,7 +485,7 @@ class HwpSys:
         Args:
              obss list of class:`Observations`: only necessary for the communicator
              pointings (float): pointing for each sample and detector
-                 generated by lbs.scanning.get_pointings
+                 generated by lbs.get_pointings
              hwp_radpsec (float): hwp rotation speed in radiants per second
         Returns:
             map (float): rebinned T,Q,U maps
